@@ -60,7 +60,7 @@ def classic_analysis(suceptibility,binder,correlation,L,rho,arr_q=[],arr_ql=[]):
 	q2=np.loadtxt('window_q2.dat')
 	q4=np.loadtxt('window_q4.dat')
 	sp=np.loadtxt('window_sp.dat')
-
+	n_instances=np.shape(q)
 
 	#Computing equilibriums
 	q=array_equilibrium(sort_and_build(q,1),'q', True,r'$T$',r'$q$')
@@ -70,7 +70,6 @@ def classic_analysis(suceptibility,binder,correlation,L,rho,arr_q=[],arr_ql=[]):
 	#Computing cumulants
 	cumulants=compute_cumulants_gammas(q2,q4,sp)
 	#Printing FSS file
-	n_instances=np.shape(q)
 	number=np.shape(q2_avg)[0]
 	fcc=open('fss.dat','w')
 	fcc.write('# Number of instances :'+str(n_instances[0]/number)+'\n')
@@ -146,7 +145,7 @@ def quantum_analysis(suceptibility,binder,correlation,L,rho,arr_q=[],arr_ql=[]):
 	q2=np.loadtxt('window_q2.dat')
 	q4=np.loadtxt('window_q4.dat')
 	sp=np.loadtxt('window_sp.dat')
-
+	n_instances=np.shape(q)
 
 	#Computing equilibriums
 	q=array_equilibrium(sort_and_build(q,1),'q', True,r'$\Gamma$',r'$q$')
@@ -156,15 +155,13 @@ def quantum_analysis(suceptibility,binder,correlation,L,rho,arr_q=[],arr_ql=[]):
 	#Computing cumulants
 	cumulants=compute_cumulants_gammas(q2,q4,sp)
 	#Printing FSS file
-	n_instances=np.shape(q)
 	number=np.shape(q2_avg)[0]
-	print(n_instances,number)
-	fcc=open('fss.dat','w')
-	fcc.write('# Number of instances :'+str(n_instances[0]/number)+'\n')
+	fss=open('fss.dat','w')
+	fss.write('# Number of instances :'+str(n_instances[0]/number)+'\n')
 	for j in cumulants:
 		#print(j)
-		fcc.write(str(j[0])+'\t'+str(L)+'\t'+str(j[1])+'\t'+str(j[2])+'\t'+str(j[3])+'\t'+str(j[4])+'\t'+str(j[5])+'\t'+str(j[6])+'\n')
-	fcc.close()
+		fss.write(str(j[0])+'\t'+str(L)+'\t'+str(j[1])+'\t'+str(j[2])+'\t'+str(j[3])+'\t'+str(j[4])+'\t'+str(j[5])+'\t'+str(j[6])+'\n')
+	fss.close()
 	# Computing histograms
 	try:
 		histogram_q=np.loadtxt('histogram_q.dat')
